@@ -19,7 +19,7 @@
 
 #include <stdarg.h>
 
-extern void open_sec_log (void);
+extern void open_sec_log (const char *program);
 
 extern void (*sec_log_fnc) (const char *program, unsigned int id, ...);
 
@@ -75,7 +75,7 @@ extern void (*sec_log_fnc) (const char *program, unsigned int id, ...);
 #define MSG_CALL_SCRIPT 44 /* variable, script, name, uid, gid, home, caller uid */
 #define MSG_ERROR_REMOVE_USER_FROM_GROUP 45 /* account, uid, group, gid, caller uid */
 #define MSG_NOT_OWNED_BY_USER 46 /* file, account, uid, caller uid */
-#define MSG_HOMEDIR_REMOVED 47 /* account, uid, home, caller uid */
+#define MSG_HOME_DIR_REMOVED 47 /* account, uid, home, caller uid */
 #define MSG_ERROR_REMOVING_USER 48 /* account, uid, caller uid */
 #define MSG_USER_DELETED 49 /* account, uid, caller uid */
 #define MSG_ERROR_RENAME_USER_IN_GROUP 50 /* account, uid, group, gid, caller uid */
@@ -83,5 +83,12 @@ extern void (*sec_log_fnc) (const char *program, unsigned int id, ...);
 #define MSG_ERROR_MODIFYING_USER 52 /* account, uid, caller uid */
 #define MSG_ACCOUNT_IN_USE 53 /* account, uid, caller uid */
 #define MSG_USER_NAME_CHANGED 54 /* new account, old account, uid, caller uid */
+#define MSG_USER_ID_CHANGED 55 /* account, new id, old id, caller id */
+#define MSG_GECOS_CHANGED 56 /* account, id, new gecos, old gecos, caller id */
+#define MSG_PRIMARY_GROUP_CHANGED 57 /* account, id, new gid, old gid, caller id */
+#define MSG_HOME_DIR_CHANGED 58 /* account, id, new home, old home, caller id */
+#define MSG_SHELL_CHANGED 59 /* account, id, new shell, old shell, caller id */
+#define MSG_INACTIVE_DAYS_CHANGED 60 /* account, id, inactive days, old value, caller id */
+#define MSG_EXPIRE_DATE_CHANGED 61 /* account, id, expire date, old date, caller id */
 
 #endif
