@@ -42,5 +42,9 @@ enum nss_status files_getgrgid_r (uid_t uid, struct group *result,
 enum nss_status files_getgrent_r (struct group *result, char *buffer,
 				  size_t buflen, int *errnop);
 
+int parse_pwent (char *line, struct passwd *result, int strict);
+int parse_spent (char *line, struct spwd *result, int strict);
+int parse_grent (char *line, struct group *result,
+		 char *buffer, size_t buflen, int *errnop, int strict);
 
 #endif /* __PUBLIC_H__ */
