@@ -36,7 +36,10 @@ strtoid (const char *arg, uint32_t *idptr)
   val = strtoll (arg, &cp, 10);
   if (*cp != '\0' ||
       ((val == LONG_LONG_MAX || val == LONG_LONG_MIN) && errno == ERANGE)
-      || val > UINT_MAX || val < 0)    /* invalid number */
+      || val > (UINT_MAX - 1) || val < 0)    /* invalid number */
+    /* (UINT_MAX -1), because we cannot chown a file to
+       UINT_MAX, which is equal to -1, which mean chown will
+       not change the file owner at all.  */
     return -1;
 
   *idptr = val;
