@@ -267,8 +267,7 @@ main (int argc, char *argv[])
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
 
-  openlog (program, LOG_PID, LOG_AUTHPRIV);
-  open_sec_log();
+  open_sec_log(program);
 
   /* Before going any further, raise the ulimit and ignore
      signals.  */
@@ -731,7 +730,7 @@ main (int argc, char *argv[])
 	printf (_("Aging information changed.\n"));
     }
 
-#if defined HAVE_LIBLAUS
+#if 0 /* XXX  logging */
   if (pw_data->sp.sp_min != pw_data->spn.sp_min)
     LAUS_LOG(NO_TAG, "chage: password minimum age changed - user=%s, uid=%u, min=%li, oldmin=%li, by=%u",
 	     pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->spn.sp_min, pw_data->sp.sp_min, uid);
