@@ -39,6 +39,9 @@
 #include <selinux/selinux.h>
 #include <selinux/av_permissions.h>
 #endif
+#ifdef HAVE_LIBNSCD_H
+#include <libnscd.h>
+#endif
 
 #include "public.h"
 #include "utf8conv.h"
@@ -728,7 +731,9 @@ main (int argc, char *argv[])
     }
   else
     {
+#ifdef HAVE_NSCD_FLUSH_CACHE
       nscd_flush_cache ("passwd");
+#endif
       if (!silent)
 	printf (_("Finger information changed.\n"));
     }
