@@ -414,7 +414,7 @@ main (int argc, char **argv)
       struct passwd resultbuf;
       struct passwd *pw;
 
-      open_sec_log ();
+      open_sec_log (program);
 
       /* Determine our own user name for PAM authentication.  */
       while (getpwuid_r (getuid (), &resultbuf, buffer, buflen, &pw) != 0
