@@ -31,7 +31,6 @@
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
-#include <syslog.h>
 #include <libgen.h>
 #include <locale.h>
 #include <libintl.h>
@@ -185,7 +184,7 @@ main (int argc, char **argv)
 
   init_environment ();
 
-  open_sec_log ();
+  open_sec_log (program);
 
   while (1)
     {
