@@ -31,7 +31,6 @@
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
-#include <syslog.h>
 #include <libgen.h>
 #include <locale.h>
 #include <libintl.h>
@@ -222,7 +221,7 @@ main (int argc, char **argv)
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
-  open_sec_log ();
+  open_sec_log (program);
 
   /* Before going any further, raise the ulimit and ignore
      signals.  */
