@@ -698,9 +698,7 @@ main (int argc, char **argv)
 
   prog = basename (argv[0]);
 
-  open_sec_log ();
-
-  openlog (prog, LOG_PID, LOG_AUTHPRIV);
+  open_sec_log (prog);
 
   /* Before going any further, raise the ulimit and ignore
      signals.  */
