@@ -44,11 +44,15 @@
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
 
+#ifdef USE_GNUTLS
+#include <gnutls/gnutls.h>
+#else
 #include <openssl/crypto.h>
 #include <openssl/x509.h>
 #include <openssl/pem.h>
 #include <openssl/ssl.h>
 #include <openssl/err.h>
+#endif
 
 #include "dbg_log.h"
 #include "rpasswd-client.h"
@@ -196,6 +200,91 @@ read_string (int echo, const char *prompt, char **retstr)
 #define CONV_ECHO_ON  1		/* types of echo state */
 #define CONV_ECHO_OFF 0
 
+#ifdef USE_GNUTLS
+static int
+handle_responses (gnutls_session ssl)
+{
+  response_header resp;
+  char retval = E_SUCCESS;
+  char *buf;
+
+  do
+    {
+      int ret;
+
+      if ((ret = gnutls_record_recv (ssl, &resp, sizeof (resp))) <= 0)
+	{
+	  if (ret == 0)
+	    fprintf (stderr, _("error while reading request: %s"),
+		     _("Peer has closed the TLS connection"));
+	  else
+	    fprintf (stderr, _("error while reading request: %s"),
+		     gnutls_strerror (ret));
+	  fputs ("\n", stderr);
+	  return E_FAILURE;
+	}
+
+      buf = alloca (resp.data_len);
+      if ((ret = gnutls_record_recv (ssl, buf, resp.data_len)) <= 0)
+	{
+	  fprintf (stderr, _("error while reading request data: %s"),
+		   gnutls_strerror (ret));
+	  fputs ("\n", stderr);
+	  return E_FAILURE;
+	}
+
+      switch (resp.type)
+	{
+	case TEXT_INFO:
+	  printf ("%s\n", buf);
+	  break;
+	case ERROR_MSG:
+	  fprintf (stderr, "%s\n", buf);
+	  break;
+	case PROMPT_ECHO_OFF:
+	  {
+	    char *string = NULL;
+	    int nc = read_string (CONV_ECHO_OFF, buf, &string);
+	    if (nc < 0)
+	      retval = send_string (ssl, PAM_CONV_ERR, string);
+	    else
+	      retval = send_string (ssl, PAM_SUCCESS, string);
+	  }
+	  break;
+	case PROMPT_ECHO_ON:
+	  {
+	    char *string = NULL;
+	    int nc = read_string (CONV_ECHO_ON, buf, &string);
+	    if (nc < 0)
+	      retval = send_string (ssl, PAM_CONV_ERR, string);
+	    else
+	      retval = send_string (ssl, PAM_SUCCESS, string);
+	  }
+	  break;
+	case FINISH:
+	  retval = buf[0];
+	  break;
+	default:
+	  break;
+	}
+
+      if ((resp.type == PROMPT_ECHO_ON || resp.type == PROMPT_ECHO_OFF) &&
+	  retval != 0)
+	{
+	  char err_buf[256];
+
+	  fprintf (stderr, _("Cannot send input back to server: %s\n"),
+		   strerror_r (errno, err_buf, sizeof (err_buf)));
+	  return E_FAILURE;
+	}
+    }
+  while (resp.type != FINISH);
+
+  return retval;
+}
+
+#else
+
 static int
 handle_responses (SSL *ssl)
 {
@@ -282,6 +371,7 @@ handle_responses (SSL *ssl)
 
   return retval;
 }
+#endif
 
 int
 main (int argc, char **argv)
@@ -298,9 +388,13 @@ main (int argc, char **argv)
   int reqcert = 3;
   int retval;
   char *username;
+#ifdef USE_GNUTLS
+  gnutls_session session;
+  gnutls_certificate_credentials xcred;
+#else
   SSL_CTX *ctx;
   SSL *ssl;
-
+#endif
 
   /* Set locale via LC_ALL.  */
   setlocale (LC_ALL, "");
@@ -481,19 +575,42 @@ main (int argc, char **argv)
     }
 
   /* Do SSL */
+#ifdef USE_GNUTLS
+  gnutls_global_init ();
+  /* Initialize TLS session. */
+  gnutls_init (&session, GNUTLS_CLIENT);
+  retval = start_ssl (sock, reqcert, verbose, session, &xcred);
+#else
   retval = start_ssl (sock, reqcert, verbose, &ctx, &ssl);
+#endif
   if (retval != 0)
     return retval;
 
+#ifdef USE_GNUTLS
+  if ((retval = start_request (session, username, admin_mode)) == 0)
+    retval = handle_responses (session);
+  else
+    retval = E_FAILURE;
+#else
   if ((retval = start_request (ssl, username, admin_mode)) == 0)
     retval = handle_responses (ssl);
   else
     retval = E_FAILURE;
+#endif
 
   free (username);
+
+#ifdef USE_GNUTLS
+  gnutls_bye (session, GNUTLS_SHUT_RDWR);
+  close (sock);
+  gnutls_deinit (session);
+  gnutls_certificate_free_credentials (xcred);
+  gnutls_global_deinit ();
+#else
   close (sock);
   SSL_free (ssl);
   SSL_CTX_free (ctx);
+#endif
 
   return retval;
 }
