@@ -31,7 +31,6 @@
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
-#include <syslog.h>
 #include <libgen.h>
 #include <locale.h>
 #include <libintl.h>
@@ -767,7 +766,7 @@ main (int argc, char **argv)
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
-  open_sec_log ();
+  open_sec_log (program);
 
   /* Before going any further, raise the ulimit and ignore
      signals.  */
@@ -1394,39 +1393,39 @@ main (int argc, char **argv)
 	  if (new_login)
 	    sec_log (program, MSG_USER_NAME_CHANGED,
 		     pw_data->new_name, pw_data->pw.pw_name,
-		     pw_data->pw.pw_uid, getuid());
-#if 0 /* XXX */
+		     pw_data->pw.pw_uid, getuid ());
 	  if (new_password)
-	    LAUS_LOG(NO_TAG, "%s: user password changed - user=%s, uid=%u, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, getuid());
+	    sec_log (program, MSG_PASSWORD_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid, getuid ());
 	  if (pw_data->new_uid)
-	    LAUS_LOG(NO_TAG, "%s: user uid changed - user=%s, uid=%u, olduid=%u, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->new_uid, pw_data->pw.pw_uid, getuid());
+	    sec_log (program, MSG_USER_ID_CHANGED,
+		     pw_data->pw.pw_name, pw_data->new_uid,
+		     pw_data->pw.pw_uid, getuid ());
 	  if (new_comment)
-	    LAUS_LOG(NO_TAG, "%s: user comment changed - user=%s, uid=%u, comment='%s', oldcomment='%s', by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->new_gecos, pw_data->pw.pw_gecos,
-		     getuid());
+	    sec_log (program, MSG_GECOS_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid,
+		     pw_data->new_gecos, pw_data->pw.pw_gecos, getuid ());
 	  if (new_group)
-	    LAUS_LOG(NO_TAG, "%s: user default gid changed - user=%s, uid=%u, gid=%u, oldgid=%u, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->new_gid,
-		     pw_data->pw.pw_gid , getuid());
+	    sec_log (program, MSG_PRIMARY_GROUP_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->new_gid,
+		     pw_data->pw.pw_gid , getuid ());
 	  if (new_home)
-	    LAUS_LOG(NO_TAG, "%s: user home directory changed - user=%s, uid=%u, home=%s, oldhome=%s, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->new_home, pw_data->pw.pw_dir,
-		     getuid());
+	    sec_log (program, MSG_HOME_DIR_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid,
+		     pw_data->new_home, pw_data->pw.pw_dir, getuid ());
 	  if (new_shell)
-	    LAUS_LOG(NO_TAG, "%s: user shell changed - user=%s, uid=%u, shell=%s, oldshell=%s, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->new_shell, pw_data->pw.pw_shell,
-		     getuid());
+	    sec_log (program, MSG_SHELL_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid,
+		     pw_data->new_shell, pw_data->pw.pw_shell, getuid ());
 	  if (know_inactive)
-	    LAUS_LOG(NO_TAG, "%s: user inactive days changed - user=%s, uid=%u, inactive=%li, oldinactive=%li, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, pw_data->spn.sp_inact, pw_data->sp.sp_inact,
-		     getuid());
+	    sec_log (program, MSG_INACTIVE_DAYS_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid,
+		     pw_data->spn.sp_inact, pw_data->sp.sp_inact, getuid ());
 	  if (know_expire)
-	    LAUS_LOG(NO_TAG, "%s: user expiration date changed - user=%s, uid=%u, expire=%s, oldexpire=%s, by=%u",
-		     program, pw_data->pw.pw_name, pw_data->pw.pw_uid, date2str(DAY*pw_data->spn.sp_expire),
-		     date2str(DAY*pw_data->sp.sp_expire), getuid());
-#endif
+	    sec_log (program, MSG_EXPIRE_DATE_CHANGED,
+		     pw_data->pw.pw_name, pw_data->pw.pw_uid,
+		     date2str(DAY*pw_data->spn.sp_expire),
+		     date2str(DAY*pw_data->sp.sp_expire), getuid ());
         }
 
 #ifdef HAVE_NSCD_FLUSH_CACHE
@@ -1443,7 +1442,9 @@ main (int argc, char **argv)
 	retval = E_FAILURE;
 
       /* Make sure, written group changes will be active now.  */
+#ifdef HAVE_NSCD_FLUSH_CACHE
       nscd_flush_cache ("group");
+#endif
     }
 
   /* Now we need to change the group file (-G/-A option).  */
@@ -1553,7 +1554,9 @@ main (int argc, char **argv)
                            gr_data->gr.gr_gid, getuid ());
 		}
 	      /* Make sure, written group changes will be active now.  */
+#ifdef HAVE_NSCD_FLUSH_CACHE
 	      nscd_flush_cache ("group");
+#endif
 	    }
 	  free_group_t (gr_data);
 	}
@@ -1653,7 +1656,9 @@ main (int argc, char **argv)
                            gr_data->gr.gr_gid, getuid ());
 		}
 	      /* Make sure, written group changes will be active now.  */
+#ifdef HAVE_NSCD_FLUSH_CACHE
 	      nscd_flush_cache ("group");
+#endif
 	    }
 	  free_group_t (gr_data);
 	}
